@@ -39,6 +39,7 @@ class OpenFaasHook(BaseHook):
 
     GET_FUNCTION = "/system/function/"
     INVOKE_ASYNC_FUNCTION = "/async-function/"
+    INVOKE_FUNCTION = "/function/"
     DEPLOY_FUNCTION = "/system/functions"
     UPDATE_FUNCTION = "/system/functions"
 
@@ -52,9 +53,7 @@ class OpenFaasHook(BaseHook):
         return conn
 
     def deploy_function(self, overwrite_function_if_exist: bool, body: Dict[str, Any]) -> None:
-        """
-        Deploy OpenFaaS function
-        """
+        """Deploy OpenFaaS function"""
         if overwrite_function_if_exist:
             self.log.info("Function already exist %s going to update", self.function_name)
             self.update_function(body)
@@ -70,11 +69,9 @@ class OpenFaasHook(BaseHook):
                 self.log.info("Function deployed %s", self.function_name)
 
     def invoke_async_function(self, body: Dict[str, Any]) -> None:
-        """
-        Invoking function
-        """
+        """Invoking function asynchronously"""
         url = self.get_conn().host + self.INVOKE_ASYNC_FUNCTION + self.function_name
-        self.log.info("Invoking function %s", url)
+        self.log.info("Invoking function asynchronously %s", url)
         response = requests.post(url, body)
         if response.ok:
             self.log.info("Invoked %s", self.function_name)
@@ -82,10 +79,21 @@ class OpenFaasHook(BaseHook):
             self.log.error("Response status %d", response.status_code)
             raise AirflowException('failed to invoke function')
 
+    def invoke_function(self, body: Dict[str, Any]) -> None:
+        """Invoking function synchronously, will block until function completes and returns"""
+        url = self.get_conn().host + self.INVOKE_FUNCTION + self.function_name
+        self.log.info("Invoking function synchronously %s", url)
+        response = requests.post(url, body)
+        if response.ok:
+            self.log.info("Invoked %s", self.function_name)
+            self.log.info("Response code %s", response.status_code)
+            self.log.info("Response %s", response.text)
+        else:
+            self.log.error("Response status %d", response.status_code)
+            raise AirflowException('failed to invoke function')
+
     def update_function(self, body: Dict[str, Any]) -> None:
-        """
-        Update OpenFaaS function
-        """
+        """Update OpenFaaS function"""
         url = self.get_conn().host + self.UPDATE_FUNCTION
         self.log.info("Updating function %s", url)
         response = requests.put(url, body)
@@ -97,9 +105,7 @@ class OpenFaasHook(BaseHook):
             self.log.info("Function was updated")
 
     def does_function_exist(self) -> bool:
-        """
-        Whether OpenFaaS function exists or not
-        """
+        """Whether OpenFaaS function exists or not"""
         url = self.get_conn().host + self.GET_FUNCTION + self.function_name
 
         response = requests.get(url)
